Aabb2 class
Constructors
Aabb2 (Vector2 min , Vector2 max )
Create a new AABB with a min and max. Aliases them rather than
copying, so both must already be immutable — this is checked with an
assertion. Copy mutable corners with Vector2.copy first if needed.
const
Aabb2.centerAndHalfExtents (Vector2 center , Vector2 halfExtents )
Create a new AABB with a center and halfExtents.
factory
Aabb2.copy (Aabb2 other )
Create a new AABB as a copy of other.
factory
Properties
center
→ Vector2
The center of the AABB. Allocates a new Vector2 .
no setter inherited
centerX
→ double
The x coordinate of the center of the AABB.
no setter inherited
centerY
→ double
The y coordinate of the center of the AABB.
no setter inherited
hashCode
→ int
The hash code for this object.
no setter inherited
height
→ double
The height of the AABB.
no setter inherited
max
→ Vector2
The maximum point defining the AABB.
final
min
→ Vector2
The minimum point defining the AABB.
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
width
→ double
The width of the AABB.
no setter inherited
Constants
zero
→ const Aabb2
Canonical zero AABB.